import { createDiscreteApi, darkTheme, lightTheme } from 'naive-ui'

// 创建全局单例
const { message, dialog, notification, loadingBar } = createDiscreteApi(
  ['message', 'dialog', 'notification', 'loadingBar'],
  {
    configProviderProps: {
      // 全局主题配置（示例使用系统主题）
      theme: window.matchMedia('(prefers-color-scheme: dark)').matches ? darkTheme : lightTheme
    }
  }
)

// 创建统一的工厂函数
const createMessager =
  (handler, defaults) =>
  (content, options = {}) => {
    const mergedOptions =
      typeof content === 'string'
        ? { content, ...defaults, ...options }
        : { ...defaults, ...content, ...options }

    return handler(mergedOptions)
  }

// 消息提示封装
export const toast = {
  info: createMessager((opts) => message.info(opts.content, opts), { duration: 3000 }),

  success: createMessager((opts) => message.success(opts.content, opts), { duration: 3000 }),

  warning: createMessager((opts) => message.warning(opts.content, opts), { duration: 5000 }),

  error: createMessager((opts) => message.error(opts.content, opts), { duration: 7000 })
}

// 通知封装
export const notify = {
  info: createMessager(notification.info, { title: '提示', duration: 3000 }),

  success: createMessager(notification.success, { title: '成功', duration: 3000 }),

  warning: createMessager(notification.warning, { title: '警告', duration: 5000 }),

  error: createMessager(notification.error, { title: '错误', duration: 7000 })
}

// 对话框封装
export const modal = {
  info: (options) => dialog.info(options),
  success: (options) => dialog.success(options),
  warning: (options) => dialog.warning(options),
  error: (options) => dialog.error(options),
  confirm: (options) => dialog.confirm(options)
}

// 加载条控制器
export const loader = {
  start: () => loadingBar.start(),
  finish: () => loadingBar.finish(),
  error: () => loadingBar.error(),
  setProgress: (progress) => loadingBar.setProgress(progress)
}
